;; Generated package description from projectile.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "projectile" "2.10.0.20260629.152" "Manage and navigate projects in Emacs easily" '((emacs "27.1") (compat "30")) :commit "e8c266ddebd1200ead1aa3c5878d7ab0d2fdf8e7" :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev")) :maintainer '("Bozhidar Batsov" . "bozhidar@batsov.dev") :keywords '("project" "convenience") :url "https://github.com/bbatsov/projectile")
