;;; Directory Local Variables
;;; For more information see (info "(emacs) Directory Variables")

((emacs-lisp-mode . ((bug-reference-url-format . "https://github.com/bbatsov/projectile/issues/%s")
                     (bug-reference-bug-regexp . "#\\(?2:[[:digit:]]+\\)")
                     (indent-tabs-mode . nil)
                     (fill-column . 80)
                     (sentence-end-double-space . t)
                     (emacs-lisp-docstring-fill-column . 75)
                     (checkdoc-symbol-words . ("top-level" "major-mode" "macroexpand-all" "print-level" "print-length"))
                     (checkdoc-package-keywords-flag . nil)
                     (checkdoc-arguments-in-order-flag . nil)
                     (checkdoc-verb-check-experimental-flag . nil))))
